# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hyperlane.core.v1 import types_pb2 as hyperlane_dot_core_dot_v1_dot_types__pb2
from hyperlane.core.interchain_security.v1 import genesis_pb2 as hyperlane_dot_core_dot_interchain__security_dot_v1_dot_genesis__pb2
from hyperlane.core.post_dispatch.v1 import genesis_pb2 as hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_genesis__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fhyperlane/core/v1/genesis.proto\x12\x11hyperlane.core.v1\x1a\x1dhyperlane/core/v1/types.proto\x1a\x33hyperlane/core/interchain_security/v1/genesis.proto\x1a-hyperlane/core/post_dispatch/v1/genesis.proto\x1a\x14gogoproto/gogo.proto\"\xd6\x03\n\x0cGenesisState\x12T\n\x0bism_genesis\x18\x01 \x01(\x0b\x32\x33.hyperlane.core.interchain_security.v1.GenesisStateR\nismGenesis\x12\x61\n\x15post_dispatch_genesis\x18\x02 \x01(\x0b\x32-.hyperlane.core.post_dispatch.v1.GenesisStateR\x13postDispatchGenesis\x12>\n\tmailboxes\x18\x03 \x03(\x0b\x32\x1a.hyperlane.core.v1.MailboxB\x04\xc8\xde\x1f\x00R\tmailboxes\x12Q\n\x08messages\x18\x04 \x03(\x0b\x32/.hyperlane.core.v1.GenesisMailboxMessageWrapperB\x04\xc8\xde\x1f\x00R\x08messages\x12!\n\x0cism_sequence\x18\x05 \x01(\x04R\x0bismSequence\x12\x34\n\x16post_dispatch_sequence\x18\x06 \x01(\x04R\x14postDispatchSequence\x12!\n\x0c\x61pp_sequence\x18\x07 \x01(\x04R\x0b\x61ppSequence\"\xa1\x01\n\x1cGenesisMailboxMessageWrapper\x12\x1d\n\nmailbox_id\x18\x01 \x01(\x04R\tmailboxId\x12\x62\n\nmessage_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmessageIdB\xc5\x01\n\x15\x63om.hyperlane.core.v1B\x0cGenesisProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\xa2\x02\x03HCX\xaa\x02\x11Hyperlane.Core.V1\xca\x02\x11Hyperlane\\Core\\V1\xe2\x02\x1dHyperlane\\Core\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Core::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.core.v1B\014GenesisProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\242\002\003HCX\252\002\021Hyperlane.Core.V1\312\002\021Hyperlane\\Core\\V1\342\002\035Hyperlane\\Core\\V1\\GPBMetadata\352\002\023Hyperlane::Core::V1'
  _globals['_GENESISSTATE'].fields_by_name['mailboxes']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['mailboxes']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['messages']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['messages']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISMAILBOXMESSAGEWRAPPER'].fields_by_name['message_id']._loaded_options = None
  _globals['_GENESISMAILBOXMESSAGEWRAPPER'].fields_by_name['message_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_GENESISSTATE']._serialized_start=208
  _globals['_GENESISSTATE']._serialized_end=678
  _globals['_GENESISMAILBOXMESSAGEWRAPPER']._serialized_start=681
  _globals['_GENESISMAILBOXMESSAGEWRAPPER']._serialized_end=842
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/warp/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dhyperlane/warp/v1/types.proto\x12\x11hyperlane.warp.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\"$\n\x06Params:\x1a\x8a\xe7\xb0*\x15hyperlane/warp/Params\"\x88\x04\n\x08HypToken\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12>\n\ntoken_type\x18\x03 \x01(\x0e\x32\x1f.hyperlane.warp.v1.HypTokenTypeR\ttokenType\x12j\n\x0eorigin_mailbox\x18\x04 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\roriginMailbox\x12!\n\x0corigin_denom\x18\x05 \x01(\tR\x0boriginDenom\x12L\n\x12\x63ollateral_balance\x18\x06 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x11\x63ollateralBalance\x12Z\n\x06ism_id\x18\x07 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\"\x95\x01\n\x0cRemoteRouter\x12\'\n\x0freceiver_domain\x18\x01 \x01(\rR\x0ereceiverDomain\x12+\n\x11receiver_contract\x18\x02 \x01(\tR\x10receiverContract\x12/\n\x03gas\x18\x03 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x03gas*q\n\x0cHypTokenType\x12\x1e\n\x1aHYP_TOKEN_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19HYP_TOKEN_TYPE_COLLATERAL\x10\x01\x12\x1c\n\x18HYP_TOKEN_TYPE_SYNTHETIC\x10\x02\x1a\x04\x88\xa3\x1e\x00\x42\xc3\x01\n\x15\x63om.hyperlane.warp.v1B\nTypesProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\xa2\x02\x03HWX\xaa\x02\x11Hyperlane.Warp.V1\xca\x02\x11Hyperlane\\Warp\\V1\xe2\x02\x1dHyperlane\\Warp\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Warp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.warp.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.warp.v1B\nTypesProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\242\002\003HWX\252\002\021Hyperlane.Warp.V1\312\002\021Hyperlane\\Warp\\V1\342\002\035Hyperlane\\Warp\\V1\\GPBMetadata\352\002\023Hyperlane::Warp::V1'
  _globals['_HYPTOKENTYPE']._loaded_options = None
  _globals['_HYPTOKENTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\212\347\260*\025hyperlane/warp/Params'
  _globals['_HYPTOKEN'].fields_by_name['id']._loaded_options = None
  _globals['_HYPTOKEN'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_HYPTOKEN'].fields_by_name['owner']._loaded_options = None
  _globals['_HYPTOKEN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_HYPTOKEN'].fields_by_name['origin_mailbox']._loaded_options = None
  _globals['_HYPTOKEN'].fields_by_name['origin_mailbox']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_HYPTOKEN'].fields_by_name['collateral_balance']._loaded_options = None
  _globals['_HYPTOKEN'].fields_by_name['collateral_balance']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_HYPTOKEN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_HYPTOKEN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_REMOTEROUTER'].fields_by_name['gas']._loaded_options = None
  _globals['_REMOTEROUTER'].fields_by_name['gas']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_HYPTOKENTYPE']._serialized_start=833
  _globals['_HYPTOKENTYPE']._serialized_end=946
  _globals['_PARAMS']._serialized_start=120
  _globals['_PARAMS']._serialized_end=156
  _globals['_HYPTOKEN']._serialized_start=159
  _globals['_HYPTOKEN']._serialized_end=679
  _globals['_REMOTEROUTER']._serialized_start=682
  _globals['_REMOTEROUTER']._serialized_end=831
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/iam/v1/iam_policy.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.google.api import client_pb2 as google_dot_api_dot_client__pb2
from pyinjective.proto.google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from pyinjective.proto.google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.iam.v1 import options_pb2 as google_dot_iam_dot_v1_dot_options__pb2
from google.iam.v1 import policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egoogle/iam/v1/iam_policy.proto\x12\rgoogle.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/iam/v1/options.proto\x1a\x1agoogle/iam/v1/policy.proto\x1a google/protobuf/field_mask.proto\"\xad\x01\n\x13SetIamPolicyRequest\x12%\n\x08resource\x18\x01 \x01(\tB\t\xe0\x41\x02\xfa\x41\x03\n\x01*R\x08resource\x12\x32\n\x06policy\x18\x02 \x01(\x0b\x32\x15.google.iam.v1.PolicyB\x03\xe0\x41\x02R\x06policy\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"w\n\x13GetIamPolicyRequest\x12%\n\x08resource\x18\x01 \x01(\tB\t\xe0\x41\x02\xfa\x41\x03\n\x01*R\x08resource\x12\x39\n\x07options\x18\x02 \x01(\x0b\x32\x1f.google.iam.v1.GetPolicyOptionsR\x07options\"i\n\x19TestIamPermissionsRequest\x12%\n\x08resource\x18\x01 \x01(\tB\t\xe0\x41\x02\xfa\x41\x03\n\x01*R\x08resource\x12%\n\x0bpermissions\x18\x02 \x03(\tB\x03\xe0\x41\x02R\x0bpermissions\">\n\x1aTestIamPermissionsResponse\x12 \n\x0bpermissions\x18\x01 \x03(\tR\x0bpermissions2\xb4\x03\n\tIAMPolicy\x12t\n\x0cSetIamPolicy\x12\".google.iam.v1.SetIamPolicyRequest\x1a\x15.google.iam.v1.Policy\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/{resource=**}:setIamPolicy:\x01*\x12t\n\x0cGetIamPolicy\x12\".google.iam.v1.GetIamPolicyRequest\x1a\x15.google.iam.v1.Policy\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/{resource=**}:getIamPolicy:\x01*\x12\x9a\x01\n\x12TestIamPermissions\x12(.google.iam.v1.TestIamPermissionsRequest\x1a).google.iam.v1.TestIamPermissionsResponse\"/\x82\xd3\xe4\x93\x02)\"$/v1/{resource=**}:testIamPermissions:\x01*\x1a\x1e\xca\x41\x1biam-meta-api.googleapis.comB\xa4\x01\n\x11\x63om.google.iam.v1B\x0eIamPolicyProtoP\x01Z)cloud.google.com/go/iam/apiv1/iampb;iampb\xa2\x02\x03GIX\xaa\x02\rGoogle.Iam.V1\xca\x02\rGoogle\\Iam\\V1\xe2\x02\x19Google\\Iam\\V1\\GPBMetadata\xea\x02\x0fGoogle::Iam::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.iam.v1.iam_policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.google.iam.v1B\016IamPolicyProtoP\001Z)cloud.google.com/go/iam/apiv1/iampb;iampb\242\002\003GIX\252\002\rGoogle.Iam.V1\312\002\rGoogle\\Iam\\V1\342\002\031Google\\Iam\\V1\\GPBMetadata\352\002\017Google::Iam::V1'
  _globals['_SETIAMPOLICYREQUEST'].fields_by_name['resource']._loaded_options = None
  _globals['_SETIAMPOLICYREQUEST'].fields_by_name['resource']._serialized_options = b'\340A\002\372A\003\n\001*'
  _globals['_SETIAMPOLICYREQUEST'].fields_by_name['policy']._loaded_options = None
  _globals['_SETIAMPOLICYREQUEST'].fields_by_name['policy']._serialized_options = b'\340A\002'
  _globals['_GETIAMPOLICYREQUEST'].fields_by_name['resource']._loaded_options = None
  _globals['_GETIAMPOLICYREQUEST'].fields_by_name['resource']._serialized_options = b'\340A\002\372A\003\n\001*'
  _globals['_TESTIAMPERMISSIONSREQUEST'].fields_by_name['resource']._loaded_options = None
  _globals['_TESTIAMPERMISSIONSREQUEST'].fields_by_name['resource']._serialized_options = b'\340A\002\372A\003\n\001*'
  _globals['_TESTIAMPERMISSIONSREQUEST'].fields_by_name['permissions']._loaded_options = None
  _globals['_TESTIAMPERMISSIONSREQUEST'].fields_by_name['permissions']._serialized_options = b'\340A\002'
  _globals['_IAMPOLICY']._loaded_options = None
  _globals['_IAMPOLICY']._serialized_options = b'\312A\033iam-meta-api.googleapis.com'
  _globals['_IAMPOLICY'].methods_by_name['SetIamPolicy']._loaded_options = None
  _globals['_IAMPOLICY'].methods_by_name['SetIamPolicy']._serialized_options = b'\202\323\344\223\002#\"\036/v1/{resource=**}:setIamPolicy:\001*'
  _globals['_IAMPOLICY'].methods_by_name['GetIamPolicy']._loaded_options = None
  _globals['_IAMPOLICY'].methods_by_name['GetIamPolicy']._serialized_options = b'\202\323\344\223\002#\"\036/v1/{resource=**}:getIamPolicy:\001*'
  _globals['_IAMPOLICY'].methods_by_name['TestIamPermissions']._loaded_options = None
  _globals['_IAMPOLICY'].methods_by_name['TestIamPermissions']._serialized_options = b'\202\323\344\223\002)\"$/v1/{resource=**}:testIamPermissions:\001*'
  _globals['_SETIAMPOLICYREQUEST']._serialized_start=256
  _globals['_SETIAMPOLICYREQUEST']._serialized_end=429
  _globals['_GETIAMPOLICYREQUEST']._serialized_start=431
  _globals['_GETIAMPOLICYREQUEST']._serialized_end=550
  _globals['_TESTIAMPERMISSIONSREQUEST']._serialized_start=552
  _globals['_TESTIAMPERMISSIONSREQUEST']._serialized_end=657
  _globals['_TESTIAMPERMISSIONSRESPONSE']._serialized_start=659
  _globals['_TESTIAMPERMISSIONSRESPONSE']._serialized_end=721
  _globals['_IAMPOLICY']._serialized_start=724
  _globals['_IAMPOLICY']._serialized_end=1160
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/iam/v1/policy.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import expr_pb2 as google_dot_type_dot_expr__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agoogle/iam/v1/policy.proto\x12\rgoogle.iam.v1\x1a\x16google/type/expr.proto\"\xab\x01\n\x06Policy\x12\x18\n\x07version\x18\x01 \x01(\x05R\x07version\x12\x32\n\x08\x62indings\x18\x04 \x03(\x0b\x32\x16.google.iam.v1.BindingR\x08\x62indings\x12?\n\raudit_configs\x18\x06 \x03(\x0b\x32\x1a.google.iam.v1.AuditConfigR\x0c\x61uditConfigs\x12\x12\n\x04\x65tag\x18\x03 \x01(\x0cR\x04\x65tag\"h\n\x07\x42inding\x12\x12\n\x04role\x18\x01 \x01(\tR\x04role\x12\x18\n\x07members\x18\x02 \x03(\tR\x07members\x12/\n\tcondition\x18\x03 \x01(\x0b\x32\x11.google.type.ExprR\tcondition\"r\n\x0b\x41uditConfig\x12\x18\n\x07service\x18\x01 \x01(\tR\x07service\x12I\n\x11\x61udit_log_configs\x18\x03 \x03(\x0b\x32\x1d.google.iam.v1.AuditLogConfigR\x0f\x61uditLogConfigs\"\xd1\x01\n\x0e\x41uditLogConfig\x12@\n\x08log_type\x18\x01 \x01(\x0e\x32%.google.iam.v1.AuditLogConfig.LogTypeR\x07logType\x12)\n\x10\x65xempted_members\x18\x02 \x03(\tR\x0f\x65xemptedMembers\"R\n\x07LogType\x12\x18\n\x14LOG_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nADMIN_READ\x10\x01\x12\x0e\n\nDATA_WRITE\x10\x02\x12\r\n\tDATA_READ\x10\x03\"\xa2\x01\n\x0bPolicyDelta\x12\x42\n\x0e\x62inding_deltas\x18\x01 \x03(\x0b\x32\x1b.google.iam.v1.BindingDeltaR\rbindingDeltas\x12O\n\x13\x61udit_config_deltas\x18\x02 \x03(\x0b\x32\x1f.google.iam.v1.AuditConfigDeltaR\x11\x61uditConfigDeltas\"\xde\x01\n\x0c\x42indingDelta\x12:\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\".google.iam.v1.BindingDelta.ActionR\x06\x61\x63tion\x12\x12\n\x04role\x18\x02 \x01(\tR\x04role\x12\x16\n\x06member\x18\x03 \x01(\tR\x06member\x12/\n\tcondition\x18\x04 \x01(\x0b\x32\x11.google.type.ExprR\tcondition\"5\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\"\xe7\x01\n\x10\x41uditConfigDelta\x12>\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32&.google.iam.v1.AuditConfigDelta.ActionR\x06\x61\x63tion\x12\x18\n\x07service\x18\x02 \x01(\tR\x07service\x12\'\n\x0f\x65xempted_member\x18\x03 \x01(\tR\x0e\x65xemptedMember\x12\x19\n\x08log_type\x18\x04 \x01(\tR\x07logType\"5\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x42\xa4\x01\n\x11\x63om.google.iam.v1B\x0bPolicyProtoP\x01Z)cloud.google.com/go/iam/apiv1/iampb;iampb\xf8\x01\x01\xa2\x02\x03GIX\xaa\x02\rGoogle.Iam.V1\xca\x02\rGoogle\\Iam\\V1\xe2\x02\x19Google\\Iam\\V1\\GPBMetadata\xea\x02\x0fGoogle::Iam::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.iam.v1.policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.google.iam.v1B\013PolicyProtoP\001Z)cloud.google.com/go/iam/apiv1/iampb;iampb\370\001\001\242\002\003GIX\252\002\rGoogle.Iam.V1\312\002\rGoogle\\Iam\\V1\342\002\031Google\\Iam\\V1\\GPBMetadata\352\002\017Google::Iam::V1'
  _globals['_POLICY']._serialized_start=70
  _globals['_POLICY']._serialized_end=241
  _globals['_BINDING']._serialized_start=243
  _globals['_BINDING']._serialized_end=347
  _globals['_AUDITCONFIG']._serialized_start=349
  _globals['_AUDITCONFIG']._serialized_end=463
  _globals['_AUDITLOGCONFIG']._serialized_start=466
  _globals['_AUDITLOGCONFIG']._serialized_end=675
  _globals['_AUDITLOGCONFIG_LOGTYPE']._serialized_start=593
  _globals['_AUDITLOGCONFIG_LOGTYPE']._serialized_end=675
  _globals['_POLICYDELTA']._serialized_start=678
  _globals['_POLICYDELTA']._serialized_end=840
  _globals['_BINDINGDELTA']._serialized_start=843
  _globals['_BINDINGDELTA']._serialized_end=1065
  _globals['_BINDINGDELTA_ACTION']._serialized_start=1012
  _globals['_BINDINGDELTA_ACTION']._serialized_end=1065
  _globals['_AUDITCONFIGDELTA']._serialized_start=1068
  _globals['_AUDITCONFIGDELTA']._serialized_end=1299
  _globals['_AUDITCONFIGDELTA_ACTION']._serialized_start=1012
  _globals['_AUDITCONFIGDELTA_ACTION']._serialized_end=1065
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/warp/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from hyperlane.warp.v1 import types_pb2 as hyperlane_dot_warp_dot_v1_dot_types__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dhyperlane/warp/v1/query.proto\x12\x11hyperlane.warp.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1dhyperlane/warp/v1/types.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\"\\\n\x12QueryTokensRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xa5\x01\n\x13QueryTokensResponse\x12\x45\n\x06tokens\x18\x01 \x03(\x0b\x32\".hyperlane.warp.v1.WrappedHypTokenB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06tokens\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"#\n\x11QueryTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"N\n\x12QueryTokenResponse\x12\x38\n\x05token\x18\x01 \x01(\x0b\x32\".hyperlane.warp.v1.WrappedHypTokenR\x05token\"\xb7\x02\n\x0fWrappedHypToken\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12>\n\ntoken_type\x18\x03 \x01(\x0e\x32\x1f.hyperlane.warp.v1.HypTokenTypeR\ttokenType\x12%\n\x0eorigin_mailbox\x18\x04 \x01(\tR\roriginMailbox\x12!\n\x0corigin_denom\x18\x05 \x01(\tR\x0boriginDenom\x12Z\n\x06ism_id\x18\x07 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\"+\n\x19QueryBridgedSupplyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"i\n\x1aQueryBridgedSupplyResponse\x12K\n\x0e\x62ridged_supply\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\rbridgedSupply\"s\n\x19QueryRemoteRoutersRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xad\x01\n\x1aQueryRemoteRoutersResponse\x12\x46\n\x0eremote_routers\x18\x01 \x03(\x0b\x32\x1f.hyperlane.warp.v1.RemoteRouterR\rremoteRouters\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\xb8\x01\n\x1fQueryQuoteRemoteTransferRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12-\n\x12\x64\x65stination_domain\x18\x02 \x01(\tR\x11\x64\x65stinationDomain\x12$\n\x0e\x63ustom_hook_id\x18\x03 \x01(\tR\x0c\x63ustomHookId\x12\x30\n\x14\x63ustom_hook_metadata\x18\x04 \x01(\tR\x12\x63ustomHookMetadata\"\x95\x01\n QueryQuoteRemoteTransferResponse\x12q\n\x0bgas_payment\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01R\ngasPayment2\x88\x06\n\x05Query\x12u\n\x06Tokens\x12%.hyperlane.warp.v1.QueryTokensRequest\x1a&.hyperlane.warp.v1.QueryTokensResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/hyperlane/v1/tokens\x12w\n\x05Token\x12$.hyperlane.warp.v1.QueryTokenRequest\x1a%.hyperlane.warp.v1.QueryTokenResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/hyperlane/v1/tokens/{id}\x12\x9e\x01\n\rBridgedSupply\x12,.hyperlane.warp.v1.QueryBridgedSupplyRequest\x1a-.hyperlane.warp.v1.QueryBridgedSupplyResponse\"0\x82\xd3\xe4\x93\x02*\x12(/hyperlane/v1/tokens/{id}/bridged_supply\x12\x9e\x01\n\rRemoteRouters\x12,.hyperlane.warp.v1.QueryRemoteRoutersRequest\x1a-.hyperlane.warp.v1.QueryRemoteRoutersResponse\"0\x82\xd3\xe4\x93\x02*\x12(/hyperlane/v1/tokens/{id}/remote_routers\x12\xcc\x01\n\x13QuoteRemoteTransfer\x12\x32.hyperlane.warp.v1.QueryQuoteRemoteTransferRequest\x1a\x33.hyperlane.warp.v1.QueryQuoteRemoteTransferResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/hyperlane/v1/tokens/{id}/quote_remote_transfer/{destination_domain}B\xc3\x01\n\x15\x63om.hyperlane.warp.v1B\nQueryProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\xa2\x02\x03HWX\xaa\x02\x11Hyperlane.Warp.V1\xca\x02\x11Hyperlane\\Warp\\V1\xe2\x02\x1dHyperlane\\Warp\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Warp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.warp.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.warp.v1B\nQueryProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\242\002\003HWX\252\002\021Hyperlane.Warp.V1\312\002\021Hyperlane\\Warp\\V1\342\002\035Hyperlane\\Warp\\V1\\GPBMetadata\352\002\023Hyperlane::Warp::V1'
  _globals['_QUERYTOKENSRESPONSE'].fields_by_name['tokens']._loaded_options = None
  _globals['_QUERYTOKENSRESPONSE'].fields_by_name['tokens']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_WRAPPEDHYPTOKEN'].fields_by_name['owner']._loaded_options = None
  _globals['_WRAPPEDHYPTOKEN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_WRAPPEDHYPTOKEN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_WRAPPEDHYPTOKEN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_QUERYBRIDGEDSUPPLYRESPONSE'].fields_by_name['bridged_supply']._loaded_options = None
  _globals['_QUERYBRIDGEDSUPPLYRESPONSE'].fields_by_name['bridged_supply']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYQUOTEREMOTETRANSFERRESPONSE'].fields_by_name['gas_payment']._loaded_options = None
  _globals['_QUERYQUOTEREMOTETRANSFERRESPONSE'].fields_by_name['gas_payment']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Tokens']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Tokens']._serialized_options = b'\202\323\344\223\002\026\022\024/hyperlane/v1/tokens'
  _globals['_QUERY'].methods_by_name['Token']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Token']._serialized_options = b'\202\323\344\223\002\033\022\031/hyperlane/v1/tokens/{id}'
  _globals['_QUERY'].methods_by_name['BridgedSupply']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BridgedSupply']._serialized_options = b'\202\323\344\223\002*\022(/hyperlane/v1/tokens/{id}/bridged_supply'
  _globals['_QUERY'].methods_by_name['RemoteRouters']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RemoteRouters']._serialized_options = b'\202\323\344\223\002*\022(/hyperlane/v1/tokens/{id}/remote_routers'
  _globals['_QUERY'].methods_by_name['QuoteRemoteTransfer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['QuoteRemoteTransfer']._serialized_options = b'\202\323\344\223\002F\022D/hyperlane/v1/tokens/{id}/quote_remote_transfer/{destination_domain}'
  _globals['_QUERYTOKENSREQUEST']._serialized_start=257
  _globals['_QUERYTOKENSREQUEST']._serialized_end=349
  _globals['_QUERYTOKENSRESPONSE']._serialized_start=352
  _globals['_QUERYTOKENSRESPONSE']._serialized_end=517
  _globals['_QUERYTOKENREQUEST']._serialized_start=519
  _globals['_QUERYTOKENREQUEST']._serialized_end=554
  _globals['_QUERYTOKENRESPONSE']._serialized_start=556
  _globals['_QUERYTOKENRESPONSE']._serialized_end=634
  _globals['_WRAPPEDHYPTOKEN']._serialized_start=637
  _globals['_WRAPPEDHYPTOKEN']._serialized_end=948
  _globals['_QUERYBRIDGEDSUPPLYREQUEST']._serialized_start=950
  _globals['_QUERYBRIDGEDSUPPLYREQUEST']._serialized_end=993
  _globals['_QUERYBRIDGEDSUPPLYRESPONSE']._serialized_start=995
  _globals['_QUERYBRIDGEDSUPPLYRESPONSE']._serialized_end=1100
  _globals['_QUERYREMOTEROUTERSREQUEST']._serialized_start=1102
  _globals['_QUERYREMOTEROUTERSREQUEST']._serialized_end=1217
  _globals['_QUERYREMOTEROUTERSRESPONSE']._serialized_start=1220
  _globals['_QUERYREMOTEROUTERSRESPONSE']._serialized_end=1393
  _globals['_QUERYQUOTEREMOTETRANSFERREQUEST']._serialized_start=1396
  _globals['_QUERYQUOTEREMOTETRANSFERREQUEST']._serialized_end=1580
  _globals['_QUERYQUOTEREMOTETRANSFERRESPONSE']._serialized_start=1583
  _globals['_QUERYQUOTEREMOTETRANSFERRESPONSE']._serialized_end=1732
  _globals['_QUERY']._serialized_start=1735
  _globals['_QUERY']._serialized_end=2511
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/post_dispatch/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from hyperlane.core.post_dispatch.v1 import types_pb2 as hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_types__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(hyperlane/core/post_dispatch/v1/tx.proto\x12\x1fhyperlane.core.post_dispatch.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a+hyperlane/core/post_dispatch/v1/types.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x91\x01\n\x0cMsgCreateIgp\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom:;\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*,hyperlane/v1/MsgCreateInterchainGasPaymaster\"k\n\x14MsgCreateIgpResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\x94\x02\n\x0eMsgSetIgpOwner\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12Z\n\x06igp_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12\x1b\n\tnew_owner\x18\x03 \x01(\tR\x08newOwner\x12-\n\x12renounce_ownership\x18\x04 \x01(\x08R\x11renounceOwnership:*\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\x1bhyperlane/v1/MsgSetIgpOwner\"\x18\n\x16MsgSetIgpOwnerResponse\"\xcd\x02\n\x1aMsgSetDestinationGasConfig\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12Z\n\x06igp_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12k\n\x16\x64\x65stination_gas_config\x18\x03 \x01(\x0b\x32\x35.hyperlane.core.post_dispatch.v1.DestinationGasConfigR\x14\x64\x65stinationGasConfig:6\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\'hyperlane/v1/MsgSetDestinationGasConfig\"$\n\"MsgSetDestinationGasConfigResponse\"\xd4\x03\n\x0cMsgPayForGas\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12Z\n\x06igp_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12\x62\n\nmessage_id\x18\x03 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmessageId\x12-\n\x12\x64\x65stination_domain\x18\x04 \x01(\rR\x11\x64\x65stinationDomain\x12:\n\tgas_limit\x18\x05 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x08gasLimit\x12<\n\x06\x61mount\x18\x06 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06\x61mount:)\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x19hyperlane/v1/MsgPayForGas\"\x16\n\x14MsgPayForGasResponse\"\xbf\x01\n\x08MsgClaim\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12Z\n\x06igp_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId:%\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x15hyperlane/v1/MsgClaim\"\x12\n\x10MsgClaimResponse\"\xe2\x01\n\x17MsgCreateMerkleTreeHook\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x62\n\nmailbox_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId:3\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*$hyperlane/v1/MsgCreateMerkleTreeHook\"v\n\x1fMsgCreateMerkleTreeHookResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"x\n\x11MsgCreateNoopHook\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner:3\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*$hyperlane/v1/MsgCreateMerkleTreeHook\"p\n\x19MsgCreateNoopHookResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id2\x88\x07\n\x03Msg\x12q\n\tCreateIgp\x12-.hyperlane.core.post_dispatch.v1.MsgCreateIgp\x1a\x35.hyperlane.core.post_dispatch.v1.MsgCreateIgpResponse\x12w\n\x0bSetIgpOwner\x12/.hyperlane.core.post_dispatch.v1.MsgSetIgpOwner\x1a\x37.hyperlane.core.post_dispatch.v1.MsgSetIgpOwnerResponse\x12\x9b\x01\n\x17SetDestinationGasConfig\x12;.hyperlane.core.post_dispatch.v1.MsgSetDestinationGasConfig\x1a\x43.hyperlane.core.post_dispatch.v1.MsgSetDestinationGasConfigResponse\x12q\n\tPayForGas\x12-.hyperlane.core.post_dispatch.v1.MsgPayForGas\x1a\x35.hyperlane.core.post_dispatch.v1.MsgPayForGasResponse\x12\x65\n\x05\x43laim\x12).hyperlane.core.post_dispatch.v1.MsgClaim\x1a\x31.hyperlane.core.post_dispatch.v1.MsgClaimResponse\x12\x92\x01\n\x14\x43reateMerkleTreeHook\x12\x38.hyperlane.core.post_dispatch.v1.MsgCreateMerkleTreeHook\x1a@.hyperlane.core.post_dispatch.v1.MsgCreateMerkleTreeHookResponse\x12\x80\x01\n\x0e\x43reateNoopHook\x12\x32.hyperlane.core.post_dispatch.v1.MsgCreateNoopHook\x1a:.hyperlane.core.post_dispatch.v1.MsgCreateNoopHookResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x94\x02\n#com.hyperlane.core.post_dispatch.v1B\x07TxProtoP\x01ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\xa2\x02\x03HCP\xaa\x02\x1eHyperlane.Core.PostDispatch.V1\xca\x02\x1eHyperlane\\Core\\PostDispatch\\V1\xe2\x02*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\xea\x02!Hyperlane::Core::PostDispatch::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.post_dispatch.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.hyperlane.core.post_dispatch.v1B\007TxProtoP\001ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\242\002\003HCP\252\002\036Hyperlane.Core.PostDispatch.V1\312\002\036Hyperlane\\Core\\PostDispatch\\V1\342\002*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\352\002!Hyperlane::Core::PostDispatch::V1'
  _globals['_MSGCREATEIGP'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATEIGP'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEIGP']._loaded_options = None
  _globals['_MSGCREATEIGP']._serialized_options = b'\202\347\260*\005owner\212\347\260*,hyperlane/v1/MsgCreateInterchainGasPaymaster'
  _globals['_MSGCREATEIGPRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATEIGPRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETIGPOWNER'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGSETIGPOWNER'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETIGPOWNER'].fields_by_name['igp_id']._loaded_options = None
  _globals['_MSGSETIGPOWNER'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETIGPOWNER']._loaded_options = None
  _globals['_MSGSETIGPOWNER']._serialized_options = b'\202\347\260*\005owner\212\347\260*\033hyperlane/v1/MsgSetIgpOwner'
  _globals['_MSGSETDESTINATIONGASCONFIG'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGSETDESTINATIONGASCONFIG'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETDESTINATIONGASCONFIG'].fields_by_name['igp_id']._loaded_options = None
  _globals['_MSGSETDESTINATIONGASCONFIG'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETDESTINATIONGASCONFIG']._loaded_options = None
  _globals['_MSGSETDESTINATIONGASCONFIG']._serialized_options = b'\202\347\260*\005owner\212\347\260*\'hyperlane/v1/MsgSetDestinationGasConfig'
  _globals['_MSGPAYFORGAS'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGPAYFORGAS'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGPAYFORGAS'].fields_by_name['igp_id']._loaded_options = None
  _globals['_MSGPAYFORGAS'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGPAYFORGAS'].fields_by_name['message_id']._loaded_options = None
  _globals['_MSGPAYFORGAS'].fields_by_name['message_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGPAYFORGAS'].fields_by_name['gas_limit']._loaded_options = None
  _globals['_MSGPAYFORGAS'].fields_by_name['gas_limit']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MSGPAYFORGAS'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGPAYFORGAS'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGPAYFORGAS']._loaded_options = None
  _globals['_MSGPAYFORGAS']._serialized_options = b'\202\347\260*\006sender\212\347\260*\031hyperlane/v1/MsgPayForGas'
  _globals['_MSGCLAIM'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGCLAIM'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCLAIM'].fields_by_name['igp_id']._loaded_options = None
  _globals['_MSGCLAIM'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCLAIM']._loaded_options = None
  _globals['_MSGCLAIM']._serialized_options = b'\202\347\260*\006sender\212\347\260*\025hyperlane/v1/MsgClaim'
  _globals['_MSGCREATEMERKLETREEHOOK'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATEMERKLETREEHOOK'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEMERKLETREEHOOK'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_MSGCREATEMERKLETREEHOOK'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATEMERKLETREEHOOK']._loaded_options = None
  _globals['_MSGCREATEMERKLETREEHOOK']._serialized_options = b'\202\347\260*\005owner\212\347\260*$hyperlane/v1/MsgCreateMerkleTreeHook'
  _globals['_MSGCREATEMERKLETREEHOOKRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATEMERKLETREEHOOKRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATENOOPHOOK'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATENOOPHOOK'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATENOOPHOOK']._loaded_options = None
  _globals['_MSGCREATENOOPHOOK']._serialized_options = b'\202\347\260*\005owner\212\347\260*$hyperlane/v1/MsgCreateMerkleTreeHook'
  _globals['_MSGCREATENOOPHOOKRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATENOOPHOOKRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATEIGP']._serialized_start=248
  _globals['_MSGCREATEIGP']._serialized_end=393
  _globals['_MSGCREATEIGPRESPONSE']._serialized_start=395
  _globals['_MSGCREATEIGPRESPONSE']._serialized_end=502
  _globals['_MSGSETIGPOWNER']._serialized_start=505
  _globals['_MSGSETIGPOWNER']._serialized_end=781
  _globals['_MSGSETIGPOWNERRESPONSE']._serialized_start=783
  _globals['_MSGSETIGPOWNERRESPONSE']._serialized_end=807
  _globals['_MSGSETDESTINATIONGASCONFIG']._serialized_start=810
  _globals['_MSGSETDESTINATIONGASCONFIG']._serialized_end=1143
  _globals['_MSGSETDESTINATIONGASCONFIGRESPONSE']._serialized_start=1145
  _globals['_MSGSETDESTINATIONGASCONFIGRESPONSE']._serialized_end=1181
  _globals['_MSGPAYFORGAS']._serialized_start=1184
  _globals['_MSGPAYFORGAS']._serialized_end=1652
  _globals['_MSGPAYFORGASRESPONSE']._serialized_start=1654
  _globals['_MSGPAYFORGASRESPONSE']._serialized_end=1676
  _globals['_MSGCLAIM']._serialized_start=1679
  _globals['_MSGCLAIM']._serialized_end=1870
  _globals['_MSGCLAIMRESPONSE']._serialized_start=1872
  _globals['_MSGCLAIMRESPONSE']._serialized_end=1890
  _globals['_MSGCREATEMERKLETREEHOOK']._serialized_start=1893
  _globals['_MSGCREATEMERKLETREEHOOK']._serialized_end=2119
  _globals['_MSGCREATEMERKLETREEHOOKRESPONSE']._serialized_start=2121
  _globals['_MSGCREATEMERKLETREEHOOKRESPONSE']._serialized_end=2239
  _globals['_MSGCREATENOOPHOOK']._serialized_start=2241
  _globals['_MSGCREATENOOPHOOK']._serialized_end=2361
  _globals['_MSGCREATENOOPHOOKRESPONSE']._serialized_start=2363
  _globals['_MSGCREATENOOPHOOKRESPONSE']._serialized_end=2475
  _globals['_MSG']._serialized_start=2478
  _globals['_MSG']._serialized_end=3382
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/post_dispatch/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+hyperlane/core/post_dispatch/v1/types.proto\x12\x1fhyperlane.core.post_dispatch.v1\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xac\x02\n\x16InterchainGasPaymaster\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x14\n\x05\x64\x65nom\x18\x03 \x01(\tR\x05\x64\x65nom\x12w\n\x0e\x63laimable_fees\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01R\rclaimableFees\"\xc8\x01\n\x14\x44\x65stinationGasConfig\x12#\n\rremote_domain\x18\x01 \x01(\rR\x0cremoteDomain\x12I\n\ngas_oracle\x18\x02 \x01(\x0b\x32*.hyperlane.core.post_dispatch.v1.GasOracleR\tgasOracle\x12@\n\x0cgas_overhead\x18\x03 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x0bgasOverhead\"\x96\x01\n\tGasOracle\x12M\n\x13token_exchange_rate\x18\x01 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x11tokenExchangeRate\x12:\n\tgas_price\x18\x02 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x08gasPrice\"\xb4\x02\n\x0eMerkleTreeHook\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12\x62\n\nmailbox_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId\x12.\n\x05owner\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x39\n\x04tree\x18\x04 \x01(\x0b\x32%.hyperlane.core.post_dispatch.v1.TreeR\x04tree\"4\n\x04Tree\x12\x16\n\x06\x62ranch\x18\x01 \x03(\x0cR\x06\x62ranch\x12\x14\n\x05\x63ount\x18\x02 \x01(\rR\x05\x63ount\"\x8f\x01\n\x08NoopHook\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05ownerB\x97\x02\n#com.hyperlane.core.post_dispatch.v1B\nTypesProtoP\x01ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\xa2\x02\x03HCP\xaa\x02\x1eHyperlane.Core.PostDispatch.V1\xca\x02\x1eHyperlane\\Core\\PostDispatch\\V1\xe2\x02*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\xea\x02!Hyperlane::Core::PostDispatch::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.post_dispatch.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.hyperlane.core.post_dispatch.v1B\nTypesProtoP\001ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\242\002\003HCP\252\002\036Hyperlane.Core.PostDispatch.V1\312\002\036Hyperlane\\Core\\PostDispatch\\V1\342\002*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\352\002!Hyperlane::Core::PostDispatch::V1'
  _globals['_INTERCHAINGASPAYMASTER'].fields_by_name['id']._loaded_options = None
  _globals['_INTERCHAINGASPAYMASTER'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_INTERCHAINGASPAYMASTER'].fields_by_name['owner']._loaded_options = None
  _globals['_INTERCHAINGASPAYMASTER'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_INTERCHAINGASPAYMASTER'].fields_by_name['claimable_fees']._loaded_options = None
  _globals['_INTERCHAINGASPAYMASTER'].fields_by_name['claimable_fees']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _globals['_DESTINATIONGASCONFIG'].fields_by_name['gas_overhead']._loaded_options = None
  _globals['_DESTINATIONGASCONFIG'].fields_by_name['gas_overhead']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_GASORACLE'].fields_by_name['token_exchange_rate']._loaded_options = None
  _globals['_GASORACLE'].fields_by_name['token_exchange_rate']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_GASORACLE'].fields_by_name['gas_price']._loaded_options = None
  _globals['_GASORACLE'].fields_by_name['gas_price']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MERKLETREEHOOK'].fields_by_name['id']._loaded_options = None
  _globals['_MERKLETREEHOOK'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MERKLETREEHOOK'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_MERKLETREEHOOK'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MERKLETREEHOOK'].fields_by_name['owner']._loaded_options = None
  _globals['_MERKLETREEHOOK'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_NOOPHOOK'].fields_by_name['id']._loaded_options = None
  _globals['_NOOPHOOK'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_NOOPHOOK'].fields_by_name['owner']._loaded_options = None
  _globals['_NOOPHOOK'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_INTERCHAINGASPAYMASTER']._serialized_start=181
  _globals['_INTERCHAINGASPAYMASTER']._serialized_end=481
  _globals['_DESTINATIONGASCONFIG']._serialized_start=484
  _globals['_DESTINATIONGASCONFIG']._serialized_end=684
  _globals['_GASORACLE']._serialized_start=687
  _globals['_GASORACLE']._serialized_end=837
  _globals['_MERKLETREEHOOK']._serialized_start=840
  _globals['_MERKLETREEHOOK']._serialized_end=1148
  _globals['_TREE']._serialized_start=1150
  _globals['_TREE']._serialized_end=1202
  _globals['_NOOPHOOK']._serialized_start=1205
  _globals['_NOOPHOOK']._serialized_end=1348
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.exchange import injective_auction_rpc_pb2 as exchange_dot_injective__auction__rpc__pb2


class InjectiveAuctionRPCStub(object):
    """InjectiveAuctionRPC defines gRPC API of the Auction API.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AuctionEndpoint = channel.unary_unary(
                '/injective_auction_rpc.InjectiveAuctionRPC/AuctionEndpoint',
                request_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionEndpointRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionEndpointResponse.FromString,
                _registered_method=True)
        self.Auctions = channel.unary_unary(
                '/injective_auction_rpc.InjectiveAuctionRPC/Auctions',
                request_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionsResponse.FromString,
                _registered_method=True)
        self.AuctionsHistoryV2 = channel.unary_unary(
                '/injective_auction_rpc.InjectiveAuctionRPC/AuctionsHistoryV2',
                request_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionsHistoryV2Request.SerializeToString,
                response_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionsHistoryV2Response.FromString,
                _registered_method=True)
        self.AuctionV2 = channel.unary_unary(
                '/injective_auction_rpc.InjectiveAuctionRPC/AuctionV2',
                request_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionV2Request.SerializeToString,
                response_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionV2Response.FromString,
                _registered_method=True)
        self.AccountAuctionsV2 = channel.unary_unary(
                '/injective_auction_rpc.InjectiveAuctionRPC/AccountAuctionsV2',
                request_serializer=exchange_dot_injective__auction__rpc__pb2.AccountAuctionsV2Request.SerializeToString,
                response_deserializer=exchange_dot_injective__auction__rpc__pb2.AccountAuctionsV2Response.FromString,
                _registered_method=True)
        self.AuctionAccountStatus = channel.unary_unary(
                '/injective_auction_rpc.InjectiveAuctionRPC/AuctionAccountStatus',
                request_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionAccountStatusRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionAccountStatusResponse.FromString,
                _registered_method=True)
        self.StreamBids = channel.unary_stream(
                '/injective_auction_rpc.InjectiveAuctionRPC/StreamBids',
                request_serializer=exchange_dot_injective__auction__rpc__pb2.StreamBidsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__auction__rpc__pb2.StreamBidsResponse.FromString,
                _registered_method=True)
        self.InjBurntEndpoint = channel.unary_unary(
                '/injective_auction_rpc.InjectiveAuctionRPC/InjBurntEndpoint',
                request_serializer=exchange_dot_injective__auction__rpc__pb2.InjBurntEndpointRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__auction__rpc__pb2.InjBurntEndpointResponse.FromString,
                _registered_method=True)
        self.AuctionsStats = channel.unary_unary(
                '/injective_auction_rpc.InjectiveAuctionRPC/AuctionsStats',
                request_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionsStatsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionsStatsResponse.FromString,
                _registered_method=True)


class InjectiveAuctionRPCServicer(object):
    """InjectiveAuctionRPC defines gRPC API of the Auction API.
    """

    def AuctionEndpoint(self, request, context):
        """Provide historical auction info for a given auction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Auctions(self, request, context):
        """Provide the historical auctions info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuctionsHistoryV2(self, request, context):
        """Provide the historical auctions info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuctionV2(self, request, context):
        """Provide historical auction info for a given auction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountAuctionsV2(self, request, context):
        """Provide the historical auctions info for a given account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuctionAccountStatus(self, request, context):
        """Get the allowlist status for a specific account in an auction round
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamBids(self, request, context):
        """StreamBids streams new bids of an auction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InjBurntEndpoint(self, request, context):
        """InjBurntEndpoint returns the total amount of INJ burnt in auctions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuctionsStats(self, request, context):
        """Returns total INJ burnt and its total USD value in auctions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveAuctionRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AuctionEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.AuctionEndpoint,
                    request_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionEndpointRequest.FromString,
                    response_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionEndpointResponse.SerializeToString,
            ),
            'Auctions': grpc.unary_unary_rpc_method_handler(
                    servicer.Auctions,
                    request_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionsRequest.FromString,
                    response_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionsResponse.SerializeToString,
            ),
            'AuctionsHistoryV2': grpc.unary_unary_rpc_method_handler(
                    servicer.AuctionsHistoryV2,
                    request_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionsHistoryV2Request.FromString,
                    response_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionsHistoryV2Response.SerializeToString,
            ),
            'AuctionV2': grpc.unary_unary_rpc_method_handler(
                    servicer.AuctionV2,
                    request_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionV2Request.FromString,
                    response_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionV2Response.SerializeToString,
            ),
            'AccountAuctionsV2': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountAuctionsV2,
                    request_deserializer=exchange_dot_injective__auction__rpc__pb2.AccountAuctionsV2Request.FromString,
                    response_serializer=exchange_dot_injective__auction__rpc__pb2.AccountAuctionsV2Response.SerializeToString,
            ),
            'AuctionAccountStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.AuctionAccountStatus,
                    request_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionAccountStatusRequest.FromString,
                    response_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionAccountStatusResponse.SerializeToString,
            ),
            'StreamBids': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamBids,
                    request_deserializer=exchange_dot_injective__auction__rpc__pb2.StreamBidsRequest.FromString,
                    response_serializer=exchange_dot_injective__auction__rpc__pb2.StreamBidsResponse.SerializeToString,
            ),
            'InjBurntEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.InjBurntEndpoint,
                    request_deserializer=exchange_dot_injective__auction__rpc__pb2.InjBurntEndpointRequest.FromString,
                    response_serializer=exchange_dot_injective__auction__rpc__pb2.InjBurntEndpointResponse.SerializeToString,
            ),
            'AuctionsStats': grpc.unary_unary_rpc_method_handler(
                    servicer.AuctionsStats,
                    request_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionsStatsRequest.FromString,
                    response_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionsStatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_auction_rpc.InjectiveAuctionRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective_auction_rpc.InjectiveAuctionRPC', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InjectiveAuctionRPC(object):
    """InjectiveAuctionRPC defines gRPC API of the Auction API.
    """

    @staticmethod
    def AuctionEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_auction_rpc.InjectiveAuctionRPC/AuctionEndpoint',
            exchange_dot_injective__auction__rpc__pb2.AuctionEndpointRequest.SerializeToString,
            exchange_dot_injective__auction__rpc__pb2.AuctionEndpointResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Auctions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_auction_rpc.InjectiveAuctionRPC/Auctions',
            exchange_dot_injective__auction__rpc__pb2.AuctionsRequest.SerializeToString,
            exchange_dot_injective__auction__rpc__pb2.AuctionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AuctionsHistoryV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_auction_rpc.InjectiveAuctionRPC/AuctionsHistoryV2',
            exchange_dot_injective__auction__rpc__pb2.AuctionsHistoryV2Request.SerializeToString,
            exchange_dot_injective__auction__rpc__pb2.AuctionsHistoryV2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AuctionV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_auction_rpc.InjectiveAuctionRPC/AuctionV2',
            exchange_dot_injective__auction__rpc__pb2.AuctionV2Request.SerializeToString,
            exchange_dot_injective__auction__rpc__pb2.AuctionV2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AccountAuctionsV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_auction_rpc.InjectiveAuctionRPC/AccountAuctionsV2',
            exchange_dot_injective__auction__rpc__pb2.AccountAuctionsV2Request.SerializeToString,
            exchange_dot_injective__auction__rpc__pb2.AccountAuctionsV2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AuctionAccountStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_auction_rpc.InjectiveAuctionRPC/AuctionAccountStatus',
            exchange_dot_injective__auction__rpc__pb2.AuctionAccountStatusRequest.SerializeToString,
            exchange_dot_injective__auction__rpc__pb2.AuctionAccountStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamBids(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/injective_auction_rpc.InjectiveAuctionRPC/StreamBids',
            exchange_dot_injective__auction__rpc__pb2.StreamBidsRequest.SerializeToString,
            exchange_dot_injective__auction__rpc__pb2.StreamBidsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InjBurntEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_auction_rpc.InjectiveAuctionRPC/InjBurntEndpoint',
            exchange_dot_injective__auction__rpc__pb2.InjBurntEndpointRequest.SerializeToString,
            exchange_dot_injective__auction__rpc__pb2.InjBurntEndpointResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AuctionsStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_auction_rpc.InjectiveAuctionRPC/AuctionsStats',
            exchange_dot_injective__auction__rpc__pb2.AuctionsStatsRequest.SerializeToString,
            exchange_dot_injective__auction__rpc__pb2.AuctionsStatsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ahyperlane/core/v1/tx.proto\x12\x11hyperlane.core.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\xcb\x03\n\x10MsgCreateMailbox\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12!\n\x0clocal_domain\x18\x02 \x01(\rR\x0blocalDomain\x12\x64\n\x0b\x64\x65\x66\x61ult_ism\x18\x03 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\ndefaultIsm\x12\x66\n\x0c\x64\x65\x66\x61ult_hook\x18\x04 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0b\x64\x65\x66\x61ultHook\x12h\n\rrequired_hook\x18\x05 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0crequiredHook:,\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\x1dhyperlane/v1/MsgCreateMailbox\"o\n\x18MsgCreateMailboxResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\xec\x04\n\rMsgSetMailbox\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x62\n\nmailbox_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId\x12\x64\n\x0b\x64\x65\x66\x61ult_ism\x18\x03 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\ndefaultIsm\x12\x66\n\x0c\x64\x65\x66\x61ult_hook\x18\x04 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0b\x64\x65\x66\x61ultHook\x12h\n\rrequired_hook\x18\x05 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0crequiredHook\x12\x35\n\tnew_owner\x18\x06 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08newOwner\x12-\n\x12renounce_ownership\x18\x07 \x01(\x08R\x11renounceOwnership:)\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\x1ahyperlane/v1/MsgSetMailbox\"\x17\n\x15MsgSetMailboxResponse\"\x92\x02\n\x11MsgProcessMessage\x12\x62\n\nmailbox_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId\x12\x32\n\x07relayer\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07relayer\x12\x1a\n\x08metadata\x18\x03 \x01(\tR\x08metadata\x12\x18\n\x07message\x18\x04 \x01(\tR\x07message:/\x82\xe7\xb0*\x07relayer\x8a\xe7\xb0*\x1ehyperlane/v1/MsgProcessMessage\"\x1b\n\x19MsgProcessMessageResponse2\xaf\x02\n\x03Msg\x12\x61\n\rCreateMailbox\x12#.hyperlane.core.v1.MsgCreateMailbox\x1a+.hyperlane.core.v1.MsgCreateMailboxResponse\x12X\n\nSetMailbox\x12 .hyperlane.core.v1.MsgSetMailbox\x1a(.hyperlane.core.v1.MsgSetMailboxResponse\x12\x64\n\x0eProcessMessage\x12$.hyperlane.core.v1.MsgProcessMessage\x1a,.hyperlane.core.v1.MsgProcessMessageResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xc0\x01\n\x15\x63om.hyperlane.core.v1B\x07TxProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\xa2\x02\x03HCX\xaa\x02\x11Hyperlane.Core.V1\xca\x02\x11Hyperlane\\Core\\V1\xe2\x02\x1dHyperlane\\Core\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Core::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.core.v1B\007TxProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\242\002\003HCX\252\002\021Hyperlane.Core.V1\312\002\021Hyperlane\\Core\\V1\342\002\035Hyperlane\\Core\\V1\\GPBMetadata\352\002\023Hyperlane::Core::V1'
  _globals['_MSGCREATEMAILBOX'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATEMAILBOX'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEMAILBOX'].fields_by_name['default_ism']._loaded_options = None
  _globals['_MSGCREATEMAILBOX'].fields_by_name['default_ism']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATEMAILBOX'].fields_by_name['default_hook']._loaded_options = None
  _globals['_MSGCREATEMAILBOX'].fields_by_name['default_hook']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATEMAILBOX'].fields_by_name['required_hook']._loaded_options = None
  _globals['_MSGCREATEMAILBOX'].fields_by_name['required_hook']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATEMAILBOX']._loaded_options = None
  _globals['_MSGCREATEMAILBOX']._serialized_options = b'\202\347\260*\005owner\212\347\260*\035hyperlane/v1/MsgCreateMailbox'
  _globals['_MSGCREATEMAILBOXRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATEMAILBOXRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETMAILBOX'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGSETMAILBOX'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETMAILBOX'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_MSGSETMAILBOX'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETMAILBOX'].fields_by_name['default_ism']._loaded_options = None
  _globals['_MSGSETMAILBOX'].fields_by_name['default_ism']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETMAILBOX'].fields_by_name['default_hook']._loaded_options = None
  _globals['_MSGSETMAILBOX'].fields_by_name['default_hook']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETMAILBOX'].fields_by_name['required_hook']._loaded_options = None
  _globals['_MSGSETMAILBOX'].fields_by_name['required_hook']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETMAILBOX'].fields_by_name['new_owner']._loaded_options = None
  _globals['_MSGSETMAILBOX'].fields_by_name['new_owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETMAILBOX']._loaded_options = None
  _globals['_MSGSETMAILBOX']._serialized_options = b'\202\347\260*\005owner\212\347\260*\032hyperlane/v1/MsgSetMailbox'
  _globals['_MSGPROCESSMESSAGE'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_MSGPROCESSMESSAGE'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGPROCESSMESSAGE'].fields_by_name['relayer']._loaded_options = None
  _globals['_MSGPROCESSMESSAGE'].fields_by_name['relayer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGPROCESSMESSAGE']._loaded_options = None
  _globals['_MSGPROCESSMESSAGE']._serialized_options = b'\202\347\260*\007relayer\212\347\260*\036hyperlane/v1/MsgProcessMessage'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATEMAILBOX']._serialized_start=143
  _globals['_MSGCREATEMAILBOX']._serialized_end=602
  _globals['_MSGCREATEMAILBOXRESPONSE']._serialized_start=604
  _globals['_MSGCREATEMAILBOXRESPONSE']._serialized_end=715
  _globals['_MSGSETMAILBOX']._serialized_start=718
  _globals['_MSGSETMAILBOX']._serialized_end=1338
  _globals['_MSGSETMAILBOXRESPONSE']._serialized_start=1340
  _globals['_MSGSETMAILBOXRESPONSE']._serialized_end=1363
  _globals['_MSGPROCESSMESSAGE']._serialized_start=1366
  _globals['_MSGPROCESSMESSAGE']._serialized_end=1640
  _globals['_MSGPROCESSMESSAGERESPONSE']._serialized_start=1642
  _globals['_MSGPROCESSMESSAGERESPONSE']._serialized_end=1669
  _globals['_MSG']._serialized_start=1672
  _globals['_MSG']._serialized_end=1975
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/post_dispatch/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from hyperlane.core.post_dispatch.v1 import types_pb2 as hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_types__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+hyperlane/core/post_dispatch/v1/query.proto\x12\x1fhyperlane.core.post_dispatch.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a+hyperlane/core/post_dispatch/v1/types.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"Z\n\x10QueryIgpsRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xb4\x01\n\x11QueryIgpsResponse\x12V\n\x04igps\x18\x01 \x03(\x0b\x32\x37.hyperlane.core.post_dispatch.v1.InterchainGasPaymasterB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x04igps\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"!\n\x0fQueryIgpRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"h\n\x10QueryIgpResponse\x12T\n\x03igp\x18\x01 \x01(\x0b\x32\x37.hyperlane.core.post_dispatch.v1.InterchainGasPaymasterB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x03igp\"{\n!QueryDestinationGasConfigsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xdc\x01\n\"QueryDestinationGasConfigsResponse\x12m\n\x17\x64\x65stination_gas_configs\x18\x01 \x03(\x0b\x32\x35.hyperlane.core.post_dispatch.v1.DestinationGasConfigR\x15\x64\x65stinationGasConfigs\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x80\x01\n\x1bQueryQuoteGasPaymentRequest\x12\x15\n\x06igp_id\x18\x01 \x01(\tR\x05igpId\x12-\n\x12\x64\x65stination_domain\x18\x02 \x01(\tR\x11\x64\x65stinationDomain\x12\x1b\n\tgas_limit\x18\x03 \x01(\tR\x08gasLimit\"\x91\x01\n\x1cQueryQuoteGasPaymentResponse\x12q\n\x0bgas_payment\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01R\ngasPayment\"e\n\x1bQueryMerkleTreeHooksRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xde\x01\n\x1cQueryMerkleTreeHooksResponse\x12u\n\x11merkle_tree_hooks\x18\x01 \x03(\x0b\x32>.hyperlane.core.post_dispatch.v1.WrappedMerkleTreeHookResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0fmerkleTreeHooks\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\",\n\x1aQueryMerkleTreeHookRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x92\x01\n\x1bQueryMerkleTreeHookResponse\x12s\n\x10merkle_tree_hook\x18\x01 \x01(\x0b\x32>.hyperlane.core.post_dispatch.v1.WrappedMerkleTreeHookResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0emerkleTreeHook\"\xb4\x01\n\x1dWrappedMerkleTreeHookResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x1d\n\nmailbox_id\x18\x03 \x01(\tR\tmailboxId\x12N\n\x0bmerkle_tree\x18\x04 \x01(\x0b\x32-.hyperlane.core.post_dispatch.v1.TreeResponseR\nmerkleTree\"N\n\x0cTreeResponse\x12\x14\n\x05leafs\x18\x01 \x03(\x0cR\x05leafs\x12\x14\n\x05\x63ount\x18\x02 \x01(\rR\x05\x63ount\x12\x12\n\x04root\x18\x03 \x01(\x0cR\x04root\"&\n\x14QueryNoopHookRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"_\n\x15QueryNoopHookResponse\x12\x46\n\tnoop_hook\x18\x01 \x01(\x0b\x32).hyperlane.core.post_dispatch.v1.NoopHookR\x08noopHook\"_\n\x15QueryNoopHooksRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xb6\x01\n\x16QueryNoopHooksResponse\x12S\n\nnoop_hooks\x18\x01 \x03(\x0b\x32).hyperlane.core.post_dispatch.v1.NoopHookB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\tnoopHooks\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination2\xff\n\n\x05Query\x12\x89\x01\n\x04Igps\x12\x31.hyperlane.core.post_dispatch.v1.QueryIgpsRequest\x1a\x32.hyperlane.core.post_dispatch.v1.QueryIgpsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/hyperlane/v1/igps\x12\x8b\x01\n\x03Igp\x12\x30.hyperlane.core.post_dispatch.v1.QueryIgpRequest\x1a\x31.hyperlane.core.post_dispatch.v1.QueryIgpResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/hyperlane/v1/igps/{id}\x12\xd9\x01\n\x15\x44\x65stinationGasConfigs\x12\x42.hyperlane.core.post_dispatch.v1.QueryDestinationGasConfigsRequest\x1a\x43.hyperlane.core.post_dispatch.v1.QueryDestinationGasConfigsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//hyperlane/v1/igps/{id}/destination_gas_configs\x12\xc5\x01\n\x0fQuoteGasPayment\x12<.hyperlane.core.post_dispatch.v1.QueryQuoteGasPaymentRequest\x1a=.hyperlane.core.post_dispatch.v1.QueryQuoteGasPaymentResponse\"5\x82\xd3\xe4\x93\x02/\x12-/hyperlane/v1/igps/{igp_id}/quote_gas_payment\x12\xb7\x01\n\x0fMerkleTreeHooks\x12<.hyperlane.core.post_dispatch.v1.QueryMerkleTreeHooksRequest\x1a=.hyperlane.core.post_dispatch.v1.QueryMerkleTreeHooksResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/hyperlane/v1/merkle_tree_hooks\x12\xb9\x01\n\x0eMerkleTreeHook\x12;.hyperlane.core.post_dispatch.v1.QueryMerkleTreeHookRequest\x1a<.hyperlane.core.post_dispatch.v1.QueryMerkleTreeHookResponse\",\x82\xd3\xe4\x93\x02&\x12$/hyperlane/v1/merkle_tree_hooks/{id}\x12\x9e\x01\n\tNoopHooks\x12\x36.hyperlane.core.post_dispatch.v1.QueryNoopHooksRequest\x1a\x37.hyperlane.core.post_dispatch.v1.QueryNoopHooksResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/hyperlane/v1/noop_hooks\x12\xa0\x01\n\x08NoopHook\x12\x35.hyperlane.core.post_dispatch.v1.QueryNoopHookRequest\x1a\x36.hyperlane.core.post_dispatch.v1.QueryNoopHookResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/hyperlane/v1/noop_hooks/{id}B\x97\x02\n#com.hyperlane.core.post_dispatch.v1B\nQueryProtoP\x01ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\xa2\x02\x03HCP\xaa\x02\x1eHyperlane.Core.PostDispatch.V1\xca\x02\x1eHyperlane\\Core\\PostDispatch\\V1\xe2\x02*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\xea\x02!Hyperlane::Core::PostDispatch::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.post_dispatch.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.hyperlane.core.post_dispatch.v1B\nQueryProtoP\001ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\242\002\003HCP\252\002\036Hyperlane.Core.PostDispatch.V1\312\002\036Hyperlane\\Core\\PostDispatch\\V1\342\002*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\352\002!Hyperlane::Core::PostDispatch::V1'
  _globals['_QUERYIGPSRESPONSE'].fields_by_name['igps']._loaded_options = None
  _globals['_QUERYIGPSRESPONSE'].fields_by_name['igps']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYIGPRESPONSE'].fields_by_name['igp']._loaded_options = None
  _globals['_QUERYIGPRESPONSE'].fields_by_name['igp']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYQUOTEGASPAYMENTRESPONSE'].fields_by_name['gas_payment']._loaded_options = None
  _globals['_QUERYQUOTEGASPAYMENTRESPONSE'].fields_by_name['gas_payment']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _globals['_QUERYMERKLETREEHOOKSRESPONSE'].fields_by_name['merkle_tree_hooks']._loaded_options = None
  _globals['_QUERYMERKLETREEHOOKSRESPONSE'].fields_by_name['merkle_tree_hooks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYMERKLETREEHOOKRESPONSE'].fields_by_name['merkle_tree_hook']._loaded_options = None
  _globals['_QUERYMERKLETREEHOOKRESPONSE'].fields_by_name['merkle_tree_hook']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYNOOPHOOKSRESPONSE'].fields_by_name['noop_hooks']._loaded_options = None
  _globals['_QUERYNOOPHOOKSRESPONSE'].fields_by_name['noop_hooks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Igps']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Igps']._serialized_options = b'\202\323\344\223\002\024\022\022/hyperlane/v1/igps'
  _globals['_QUERY'].methods_by_name['Igp']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Igp']._serialized_options = b'\202\323\344\223\002\031\022\027/hyperlane/v1/igps/{id}'
  _globals['_QUERY'].methods_by_name['DestinationGasConfigs']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DestinationGasConfigs']._serialized_options = b'\202\323\344\223\0021\022//hyperlane/v1/igps/{id}/destination_gas_configs'
  _globals['_QUERY'].methods_by_name['QuoteGasPayment']._loaded_options = None
  _globals['_QUERY'].methods_by_name['QuoteGasPayment']._serialized_options = b'\202\323\344\223\002/\022-/hyperlane/v1/igps/{igp_id}/quote_gas_payment'
  _globals['_QUERY'].methods_by_name['MerkleTreeHooks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MerkleTreeHooks']._serialized_options = b'\202\323\344\223\002!\022\037/hyperlane/v1/merkle_tree_hooks'
  _globals['_QUERY'].methods_by_name['MerkleTreeHook']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MerkleTreeHook']._serialized_options = b'\202\323\344\223\002&\022$/hyperlane/v1/merkle_tree_hooks/{id}'
  _globals['_QUERY'].methods_by_name['NoopHooks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NoopHooks']._serialized_options = b'\202\323\344\223\002\032\022\030/hyperlane/v1/noop_hooks'
  _globals['_QUERY'].methods_by_name['NoopHook']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NoopHook']._serialized_options = b'\202\323\344\223\002\037\022\035/hyperlane/v1/noop_hooks/{id}'
  _globals['_QUERYIGPSREQUEST']._serialized_start=272
  _globals['_QUERYIGPSREQUEST']._serialized_end=362
  _globals['_QUERYIGPSRESPONSE']._serialized_start=365
  _globals['_QUERYIGPSRESPONSE']._serialized_end=545
  _globals['_QUERYIGPREQUEST']._serialized_start=547
  _globals['_QUERYIGPREQUEST']._serialized_end=580
  _globals['_QUERYIGPRESPONSE']._serialized_start=582
  _globals['_QUERYIGPRESPONSE']._serialized_end=686
  _globals['_QUERYDESTINATIONGASCONFIGSREQUEST']._serialized_start=688
  _globals['_QUERYDESTINATIONGASCONFIGSREQUEST']._serialized_end=811
  _globals['_QUERYDESTINATIONGASCONFIGSRESPONSE']._serialized_start=814
  _globals['_QUERYDESTINATIONGASCONFIGSRESPONSE']._serialized_end=1034
  _globals['_QUERYQUOTEGASPAYMENTREQUEST']._serialized_start=1037
  _globals['_QUERYQUOTEGASPAYMENTREQUEST']._serialized_end=1165
  _globals['_QUERYQUOTEGASPAYMENTRESPONSE']._serialized_start=1168
  _globals['_QUERYQUOTEGASPAYMENTRESPONSE']._serialized_end=1313
  _globals['_QUERYMERKLETREEHOOKSREQUEST']._serialized_start=1315
  _globals['_QUERYMERKLETREEHOOKSREQUEST']._serialized_end=1416
  _globals['_QUERYMERKLETREEHOOKSRESPONSE']._serialized_start=1419
  _globals['_QUERYMERKLETREEHOOKSRESPONSE']._serialized_end=1641
  _globals['_QUERYMERKLETREEHOOKREQUEST']._serialized_start=1643
  _globals['_QUERYMERKLETREEHOOKREQUEST']._serialized_end=1687
  _globals['_QUERYMERKLETREEHOOKRESPONSE']._serialized_start=1690
  _globals['_QUERYMERKLETREEHOOKRESPONSE']._serialized_end=1836
  _globals['_WRAPPEDMERKLETREEHOOKRESPONSE']._serialized_start=1839
  _globals['_WRAPPEDMERKLETREEHOOKRESPONSE']._serialized_end=2019
  _globals['_TREERESPONSE']._serialized_start=2021
  _globals['_TREERESPONSE']._serialized_end=2099
  _globals['_QUERYNOOPHOOKREQUEST']._serialized_start=2101
  _globals['_QUERYNOOPHOOKREQUEST']._serialized_end=2139
  _globals['_QUERYNOOPHOOKRESPONSE']._serialized_start=2141
  _globals['_QUERYNOOPHOOKRESPONSE']._serialized_end=2236
  _globals['_QUERYNOOPHOOKSREQUEST']._serialized_start=2238
  _globals['_QUERYNOOPHOOKSREQUEST']._serialized_end=2333
  _globals['_QUERYNOOPHOOKSRESPONSE']._serialized_start=2336
  _globals['_QUERYNOOPHOOKSRESPONSE']._serialized_end=2518
  _globals['_QUERY']._serialized_start=2521
  _globals['_QUERY']._serialized_end=3928
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/interchain_security/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1hyperlane/core/interchain_security/v1/types.proto\x12%hyperlane.core.interchain_security.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"|\n\x05Route\x12U\n\x03ism\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x03ism\x12\x16\n\x06\x64omain\x18\x02 \x01(\rR\x06\x64omain:\x04\x88\xa0\x1f\x00\"\xae\x02\n\nRoutingISM\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12J\n\x06routes\x18\x03 \x03(\x0b\x32,.hyperlane.core.interchain_security.v1.RouteB\x04\xc8\xde\x1f\x00R\x06routes:O\x88\xa0\x1f\x00\xca\xb4-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule\"\xaa\x02\n\x14MessageIdMultisigISM\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x1e\n\nvalidators\x18\x03 \x03(\tR\nvalidators\x12\x1c\n\tthreshold\x18\x04 \x01(\rR\tthreshold:O\x88\xa0\x1f\x00\xca\xb4-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule\"\xab\x02\n\x15MerkleRootMultisigISM\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x1e\n\nvalidators\x18\x03 \x03(\tR\nvalidators\x12\x1c\n\tthreshold\x18\x04 \x01(\rR\tthreshold:O\x88\xa0\x1f\x00\xca\xb4-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule\"\xdf\x01\n\x07NoopISM\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner:O\x88\xa0\x1f\x00\xca\xb4-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModuleB\xbb\x02\n)com.hyperlane.core.interchain_security.v1B\nTypesProtoP\x01ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\xa2\x02\x03HCI\xaa\x02$Hyperlane.Core.InterchainSecurity.V1\xca\x02$Hyperlane\\Core\\InterchainSecurity\\V1\xe2\x02\x30Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\xea\x02\'Hyperlane::Core::InterchainSecurity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.interchain_security.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.hyperlane.core.interchain_security.v1B\nTypesProtoP\001ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\242\002\003HCI\252\002$Hyperlane.Core.InterchainSecurity.V1\312\002$Hyperlane\\Core\\InterchainSecurity\\V1\342\0020Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\352\002\'Hyperlane::Core::InterchainSecurity::V1'
  _globals['_ROUTE'].fields_by_name['ism']._loaded_options = None
  _globals['_ROUTE'].fields_by_name['ism']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_ROUTE']._loaded_options = None
  _globals['_ROUTE']._serialized_options = b'\210\240\037\000'
  _globals['_ROUTINGISM'].fields_by_name['id']._loaded_options = None
  _globals['_ROUTINGISM'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_ROUTINGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_ROUTINGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_ROUTINGISM'].fields_by_name['routes']._loaded_options = None
  _globals['_ROUTINGISM'].fields_by_name['routes']._serialized_options = b'\310\336\037\000'
  _globals['_ROUTINGISM']._loaded_options = None
  _globals['_ROUTINGISM']._serialized_options = b'\210\240\037\000\312\264-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule'
  _globals['_MESSAGEIDMULTISIGISM'].fields_by_name['id']._loaded_options = None
  _globals['_MESSAGEIDMULTISIGISM'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MESSAGEIDMULTISIGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_MESSAGEIDMULTISIGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MESSAGEIDMULTISIGISM']._loaded_options = None
  _globals['_MESSAGEIDMULTISIGISM']._serialized_options = b'\210\240\037\000\312\264-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule'
  _globals['_MERKLEROOTMULTISIGISM'].fields_by_name['id']._loaded_options = None
  _globals['_MERKLEROOTMULTISIGISM'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MERKLEROOTMULTISIGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_MERKLEROOTMULTISIGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MERKLEROOTMULTISIGISM']._loaded_options = None
  _globals['_MERKLEROOTMULTISIGISM']._serialized_options = b'\210\240\037\000\312\264-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule'
  _globals['_NOOPISM'].fields_by_name['id']._loaded_options = None
  _globals['_NOOPISM'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_NOOPISM'].fields_by_name['owner']._loaded_options = None
  _globals['_NOOPISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_NOOPISM']._loaded_options = None
  _globals['_NOOPISM']._serialized_options = b'\210\240\037\000\312\264-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule'
  _globals['_ROUTE']._serialized_start=141
  _globals['_ROUTE']._serialized_end=265
  _globals['_ROUTINGISM']._serialized_start=268
  _globals['_ROUTINGISM']._serialized_end=570
  _globals['_MESSAGEIDMULTISIGISM']._serialized_start=573
  _globals['_MESSAGEIDMULTISIGISM']._serialized_end=871
  _globals['_MERKLEROOTMULTISIGISM']._serialized_start=874
  _globals['_MERKLEROOTMULTISIGISM']._serialized_end=1173
  _globals['_NOOPISM']._serialized_start=1176
  _globals['_NOOPISM']._serialized_end=1399
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/downtimedetector/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.downtimedetector.v1beta1 import genesis_pb2 as injective_dot_downtimedetector_dot_v1beta1_dot_genesis__pb2
from pyinjective.proto.injective.downtimedetector.v1beta1 import downtime_duration_pb2 as injective_dot_downtimedetector_dot_v1beta1_dot_downtime__duration__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.injective/downtimedetector/v1beta1/query.proto\x12\"injective.downtimedetector.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x30injective/downtimedetector/v1beta1/genesis.proto\x1a:injective/downtimedetector/v1beta1/downtime_duration.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe3\x01\n%RecoveredSinceDowntimeOfLengthRequest\x12]\n\x08\x64owntime\x18\x01 \x01(\x0e\x32,.injective.downtimedetector.v1beta1.DowntimeB\x13\xf2\xde\x1f\x0fyaml:\"downtime\"R\x08\x64owntime\x12[\n\x08recovery\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB$\xc8\xde\x1f\x00\xf2\xde\x1f\x18yaml:\"recovery_duration\"\x98\xdf\x1f\x01R\x08recovery\"_\n&RecoveredSinceDowntimeOfLengthResponse\x12\x35\n\x16successfully_recovered\x18\x01 \x01(\x08R\x15successfullyRecovered2\x91\x02\n\x05Query\x12\x87\x02\n\x1eRecoveredSinceDowntimeOfLength\x12I.injective.downtimedetector.v1beta1.RecoveredSinceDowntimeOfLengthRequest\x1aJ.injective.downtimedetector.v1beta1.RecoveredSinceDowntimeOfLengthResponse\"N\x82\xd3\xe4\x93\x02H\"C/injective/downtime-detector/v1beta1/RecoveredSinceDowntimeOfLength:\x01*B\xb7\x02\n&com.injective.downtimedetector.v1beta1B\nQueryProtoP\x01ZWgithub.com/InjectiveLabs/injective-core/injective-chain/modules/downtime-detector/types\xa2\x02\x03IDX\xaa\x02\"Injective.Downtimedetector.V1beta1\xca\x02\"Injective\\Downtimedetector\\V1beta1\xe2\x02.Injective\\Downtimedetector\\V1beta1\\GPBMetadata\xea\x02$Injective::Downtimedetector::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.downtimedetector.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.injective.downtimedetector.v1beta1B\nQueryProtoP\001ZWgithub.com/InjectiveLabs/injective-core/injective-chain/modules/downtime-detector/types\242\002\003IDX\252\002\"Injective.Downtimedetector.V1beta1\312\002\"Injective\\Downtimedetector\\V1beta1\342\002.Injective\\Downtimedetector\\V1beta1\\GPBMetadata\352\002$Injective::Downtimedetector::V1beta1'
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST'].fields_by_name['downtime']._loaded_options = None
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST'].fields_by_name['downtime']._serialized_options = b'\362\336\037\017yaml:\"downtime\"'
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST'].fields_by_name['recovery']._loaded_options = None
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST'].fields_by_name['recovery']._serialized_options = b'\310\336\037\000\362\336\037\030yaml:\"recovery_duration\"\230\337\037\001'
  _globals['_QUERY'].methods_by_name['RecoveredSinceDowntimeOfLength']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RecoveredSinceDowntimeOfLength']._serialized_options = b'\202\323\344\223\002H\"C/injective/downtime-detector/v1beta1/RecoveredSinceDowntimeOfLength:\001*'
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST']._serialized_start=444
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST']._serialized_end=671
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHRESPONSE']._serialized_start=673
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHRESPONSE']._serialized_end=768
  _globals['_QUERY']._serialized_start=771
  _globals['_QUERY']._serialized_end=1044
# @@protoc_insertion_point(module_scope)
